@@ -1,12 +1,17 @@
 from .tools import (
     CoingeckoUniversalQuoteTool,
-    FinBERTSentimentAnalysisTool,
     SerperDevTool,
     SerplyNewsSearchTool,
     ScrapeWebsiteTool,
     JSONSearchTool,
     RagTool,
     S3ReaderTool,
-    S3WriterTool
+    S3WriterTool,
+    FileReadTool,
+    KeywordSearchTool,
+    VectorSearchTool,
+    CapabilitiesTagsSearchTool,
+    ListAgentsTool,
+    get_iatp_search_tools
 )
 from .index import get_traia_tools_index
\ No newline at end of file
