@@ -1,22 +1,34 @@
 from .coingecko_quote_tool.coingecko_quote_tool import CoingeckoUniversalQuoteTool
-from .sentiment_analysis_tool.sentiment_analysis_tool import FinBERTSentimentAnalysisTool
 
 from .scrape_website_tool.scrape_website_tool import ScrapeWebsiteTool
 from .serply_news_search_tool.serply_news_search_tool import SerplyNewsSearchTool
 from .serper_dev_tool.serper_dev_tool import SerperDevTool
 from .json_search_tool.json_search_tool import JSONSearchTool
+from .file_read_tool.file_read_tool import FileReadTool
 from .rag_tool.rag_tool import RagTool
 from .s3_reader_tool.s3_reader_tool import S3ReaderTool
 from .s3_writer_tool.s3_writer_tool import S3WriterTool
+from .iatp_search_tool.iatp_search_tool import (
+    KeywordSearchTool,
+    VectorSearchTool,
+    CapabilitiesTagsSearchTool,
+    ListAgentsTool,
+    get_iatp_search_tools
+)
 
 __all__ = [
     'CoingeckoUniversalQuoteTool',
-    'FinBERTSentimentAnalysisTool',
     'ScrapeWebsiteTool',
     'SerplyNewsSearchTool',
     'SerperDevTool',
     'JSONSearchTool',
+    'FileReadTool',
     'RagTool',
     'S3ReaderTool',
-    'S3WriterTool'
+    'S3WriterTool',
+    'KeywordSearchTool',
+    'VectorSearchTool',
+    'CapabilitiesTagsSearchTool',
+    'ListAgentsTool',
+    'get_iatp_search_tools'
 ]
\ No newline at end of file
